<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX kodektelepítő</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some jurisdictions, their distribution may be limited. Please check the regulations in your area. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Ez az alkalmazás lehetővé teszi letiltott kodekek telepítését, amelyek fejlett videó és hang funkciókat engedélyeznek.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;Egyes törvénykezésekben, ezek megosztása korlátozott lehet. Kérjük ellenőrizze régiója törvényes rendelkezéseit.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Törvényes felelősségének tudatában le akarja tölteni ezeket a kodekeket?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Kodekfájlok letöltése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Cancel any changes then quit</source>
        <translation>Változtatások visszavonása és kilépés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Begin codec download and installation</source>
        <translation>Kodek letöltése és telepítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>About this application</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <source>About...</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Display help </source>
        <translation>Súgó megjelenítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Parancs futtatása...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="151"/>
        <location filename="../mainwindow.cpp" line="171"/>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <source>Cannot connect to the download site</source>
        <translation>Nem sikerült a csatlakozás a letöltőoldalhoz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Error downloading %1</source>
        <translation>Hibás letöltés %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="111"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="152"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>downloading Packages.gz from &apos;main&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>downloading Packages.gz from &apos;non-free&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>downloading Packages.gz from i386 &apos;main&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;A letöltés kész.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Cannot connect find %1 package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Installing downloaded files</source>
        <translation>Letöltött fájlok telepítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>No downloaded *.debs files found.</source>
        <translation>A letöltött *.deb fájlok nem találhatóak.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Telepítés...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>Error installing %1</source>
        <translation>Hibás telepítés %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>Fix missing dependencies...</source>
        <translation>Javítsd a hiányzó tartozékokat...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Error running %1 command</source>
        <translation>Hiba történt %1 parancs futtatásakor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;A telepítési folyamat kész&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Finished</source>
        <translation>Kész</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Kodekfájlok sikeresen letöltve és telepítve.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>A folyamat kész. Hibák történtek a telepítés során.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>About MX Codecs</source>
        <translation>Az MX kodektelepítőről</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MX Codecs</source>
        <translation type="vanished">MX kodektelepítő</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Version: </source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Egyszerű kodekletöltő MX Linuxhoz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenc</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Változások listája</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Bezárás</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to get exclusive lock</source>
        <translation type="vanished">Kizárólagos zárolás nem elérhető</translation>
    </message>
    <message>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="vanished">Egy másik csomagkezelő alkalmazás (vagy a Synaptic, vagy az apt-get) már fut. Kérem zárja be először ezt az alkalmazást!</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Root felhasználóként kell futtatnia ezt a programot!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Licenc</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation type="unfinished">Változások listája</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation type="unfinished">Mégsem</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Bezárás</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished">Hiba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>Unable to get exclusive lock</source>
        <translation type="unfinished">Kizárólagos zárolás nem elérhető</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="unfinished">Egy másik csomagkezelő alkalmazás (vagy a Synaptic, vagy az apt-get) már fut. Kérem zárja be először ezt az alkalmazást!</translation>
    </message>
</context>
</TS>
